@@ -5,11 +5,11 @@ use strict;
 #use bytes;
 
 our @EXPORT    = qw( sendmsg recvmsg );
-our @EXPORT_OK = qw( pack_cmsghdr unpack_cmsghdr ); # Undocumented!
-our $VERSION = '0.04_03';
+our @EXPORT_OK = qw( pack_cmsghdr unpack_cmsghdr );
+our $VERSION = '0.02';
 
 # Forcibly export our sendmsg, recvmsg methods
-BEGIN {
+INIT {
   *IO::Socket::sendmsg = \&sendmsg;
   *IO::Socket::recvmsg = \&recvmsg;
 }
@@ -23,7 +23,7 @@ sub flags {
   $self->{flags};
 }
 
-BEGIN {
+INIT {
   for my $attr (qw|name buf control|) {
     no strict 'refs';
 
@@ -140,7 +140,7 @@ Socket::MsgHdr - sendmsg, recvmsg and ancillary data operations
   $outHdr->cmsghdr(SOL_SOCKET,                # cmsg_level
                    SCM_RIGHTS,                # cmsg_type
                    pack("i", fileno(STDIN))); # cmsg_data
-  sendmsg(OUT, $outHdr);
+  sendmsg(OUT, $msgHdr);
 
   # Unpack the same
   my $inHdr = Socket::MsgHdr->new(buflen => 8192, controllen => 256);
@@ -189,12 +189,8 @@ I<controllen> bytes of ancillary data.
 Returns number of bytes received, or undef on failure.  I<buflen>
 et. al. are updated to reflect the actual lengths of received data.
 
-=back
-
 =head2 Socket::MsgHdr
 
-=over 4
-
 =item new [PARAMETERS]
 
 Return a new Socket::MsgHdr object.  Optional PARAMETERS may specify method
@@ -280,17 +276,19 @@ module.
 
 =head1 SEE ALSO
 
-L<sendmsg(2)>, L<recvmsg(2)>, L<File::FDpasser>, L<RFC 2292|https://tools.ietf.org/html/rfc2292>
+L<sendmsg(2)>, L<recvmsg(2)>, L<File::FDpasser>, L<"RFC 2292">
 
 =head1 AUTHOR
 
-Michael J. Pomraning, co-maintained by Felipe Gasper
+Michael J. Pomraning
+
+Please report bugs to E<lt>mjp-perl AT pilcrow.madison.wi.us E<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003, 2010 by Michael J. Pomraning
+Copyright 2003 by Michael J. Pomraning
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
